﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using MindFusion.Charting;

using SolidBrush = MindFusion.Drawing.SolidBrush;


namespace PieChart
{
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();

			pieChart.ShowLegend = false;
			
			var values = new List<double> { 20, 30, 10, 40 };
			pieChart.Series = new PieSeries(
				values,
				new List<string>()
				{
					"20", "30", "10", "40"
				},
				new List<string>()
				{
					"twenty", "thirty", "ten", "forty"
				}
			);

			pieChart.Plot.SeriesStyle = new PerElementSeriesStyle()
			{
				Fills = new List<List<MindFusion.Drawing.Brush>>()
				{
					new List<MindFusion.Drawing.Brush>()
					{
						new SolidBrush(Color.FromArgb(224, 233, 233)),					
						new SolidBrush(Color.FromArgb(102, 154, 204)),					
						new SolidBrush(Color.FromArgb(192, 192, 192)),				
						new SolidBrush(Color.FromArgb(206, 0, 0))
					}
				}
			};
			for (int i = 0; i < values.Count; i++)
				lbDetached.Items.Add(i);
		}

		void chbDonut_CheckedChanged(object sender, EventArgs e)
		{
			pieChart.Doughnut = !pieChart.Doughnut;
			pieChart.Invalidate();
		}

		void tbRadius_Scroll(object sender, EventArgs e)
		{
			pieChart.ChartPadding = tbRadius.Value;
			pieChart.Invalidate();
		}

		void chbAllowRotate_CheckedChanged(object sender, EventArgs e)
		{
			pieChart.AllowRotate = !pieChart.AllowRotate;
		}

		void tbDetachOffset_Scroll(object sender, EventArgs e)
		{
			pieChart.DetachOffset = (float)tbDetachOffset.Value;
			pieChart.Invalidate();
		}

		void lbDetached_SelectedIndexChanged(object sender, EventArgs e)
		{
			List<int> o = new List<int>();
			foreach (var s in lbDetached.SelectedIndices)
			{
				o.Add((int)s);
			}
			pieChart.DetachedSlices = o;
			pieChart.Invalidate();
		}

		void tbStartAngle_Scroll(object sender, EventArgs e)
		{
			pieChart.StartAngle = tbStartAngle.Value;
			pieChart.Invalidate();
		}

		void chbShowDataLabels_CheckedChanged(object sender, EventArgs e)
		{
			if (chbShowDataLabels.Checked)
				pieChart.ShowDataLabels = LabelKinds.All;
			else
				pieChart.ShowDataLabels = LabelKinds.None;
			pieChart.Invalidate();
		}
	}
}